@@ -2,7 +2,7 @@ package MooseX::App;
 # ============================================================================«
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use strict;
 use warnings;
@@ -12,7 +12,6 @@ use MooseX::App::Meta::Role::Attribute::Option;
 
 my ($IMPORT,$UNIMPORT,$INIT_META) = Moose::Exporter->build_import_methods(
     with_meta           => [ 'app_namespace','app_base', 'option' ],
-    as_is               => [ '_compute_getopt_attrs' ],
     also                => 'Moose',
     install             => [qw(unimport init_meta)],
 );
@@ -53,7 +52,7 @@ sub init_meta {
         class               => ['MooseX::App::Meta::Role::Class::Base'],
         attribute           => ['MooseX::App::Meta::Role::Attribute::Base'],
     );
-    my @apply_roles     = ('MooseX::App::Base');
+    my @apply_roles     = ('MooseX::App::Base','MooseX::App::Common');
     
     foreach my $plugin (@$plugins) {
         push(@apply_roles,$plugin,{ -excludes => [ 'plugin_metaroles' ] } )
@@ -123,16 +122,6 @@ sub app_base($) {
     return $meta->app_base($name);
 }
 
-# Dirty hack to hide private attributes from MooseX-Getopt
-sub _compute_getopt_attrs {
-    my ($class) = @_;
-
-    return
-        sort { $a->insertion_order <=> $b->insertion_order }
-        grep { $_->does('AppOption') } 
-        $class->meta->get_all_attributes
-}
-
 no Moose;
 1;
 
