@@ -10,7 +10,6 @@ use Moose::Exporter;
 
 Moose::Exporter->setup_import_methods(
     with_meta => [ 'command_short_description', 'command_long_description', 'option'],
-    as_is     => ['_compute_getopt_attrs'],
     also      => 'Moose',
 );
 
@@ -33,7 +32,7 @@ sub init_meta {
     
     Moose::Util::MetaRole::apply_base_class_roles(
         for             => $args{for_class},
-        roles           => ['MooseX::Getopt'],
+        roles           => ['MooseX::App::Common'],
     );
     
     return $meta;
@@ -53,16 +52,6 @@ sub option {
     goto &MooseX::App::option;
 }
 
-# Dirty hack to hide private attributes from MooseX-Getopt
-sub _compute_getopt_attrs {
-    my ($class) = @_;
-
-    return
-        sort { $a->insertion_order <=> $b->insertion_order }
-        grep { $_->does('AppOption') } 
-        $class->meta->get_all_attributes
-}
-
 1;
 
 __END__
