@@ -5,4 +5,8 @@ use MooseX::App qw(BashCompletion ConfigHome Color);
 
 app_namespace "Test02::Command";
 
+sub run {
+    print "RAN";   
+}
+
 1;
\ No newline at end of file
